(*
This file is part of OCamlRPM.

OCamlRPM is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

OCamlRPM is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with OCamlRPM; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*)

type rpm_dep_type =
  Compile | Install | Delete | Run | Recommend | Suggest | Provide | Conflict | Replace

type rpm_dep_version =
  AllVersions |
  Equal of string |
  Earlier of string |
  Later of string |
  EarlierEqual of string |
  LaterEqual of string

type rpm_dependency =
{
  dep_target: string;
  dep_version: rpm_dep_version
}

type rpm_dep_alternative = rpm_dependency list 

type rpm_dep_expression = rpm_dep_type * (rpm_dep_alternative list)

type rpm_metadata =
{
  name: string;
  version: string;
  filename: string;
  dependencies: rpm_dep_expression list;
  architecture: string;
  files: (string * string) list;
  maintainer: string;
  category: string;
	size: int32;
  installed_size: int32;
  source_package: string;
  source_version: string;
  homepage: string;
  summary: string;
  description: string;
  license: string;
  distribution: string;
  vendor: string;
  essential: bool;
  build_essential: bool;
  os: string;
  date: int32
}

val read_package: string -> string -> rpm_metadata
val read_hdlist: string -> string -> rpm_metadata list
